@@ -454,6 +454,7 @@ class Agent:
             get_agent_memory=default_get_agent_memory, # skills.codyer.llm.get_agent_memory，已经没有用了
             read_files = [], # 参考文件列表，只能读取.md、txt、py、js等文本文件
             show_step_detail=False, # 是否显示每一步的执行信息细节
+            show_messages=False
         ):
         """
         @role: str, agent role description
@@ -469,6 +470,7 @@ class Agent:
         @interpretors: list, 解析器 [(is_match, parse, realtime|final), ...]. is_match(llm_output) -> bool, parse(llm_output) -> (python_mode, python_result, result, continue_run)
             parse: return (python_mode, python_result, result, continue_run)
         @with_file_operator: bool, 是否启用文件操作
+        @show_messages: 是否显示消息
         """
         if workspace is not None and not os.path.exists(workspace):
             os.makedirs(workspace)
@@ -520,6 +522,7 @@ class Agent:
         self._read_files = read_files
         self._tmp_read_files = []
         self._show_step_detail = show_step_detail
+        self._show_messages = show_messages
 
     def is_file_read_operator(self, llm_output):
         """检查是否包含读文件操作"""
@@ -621,7 +624,7 @@ class Agent:
                 the_role = 'assistant' if role == 'user' else 'user' # 压缩消息后，和下一条消息的角色保持区分，避免消息合并
             self.messages = [{"role": the_role, "content": summary}] + left_messages
             if self._show_step_detail:
-                token_count = self.llm_token_count(self.messages)
+                token_count = int(self.llm_token_count(self.messages))
                 self.stream_output(f'\n处理后长度为 {token_count}\n```\n')
             #     self.stream_output(f'压缩后内容: \n---------\n{summary}\n---------\n')
         
@@ -850,8 +853,9 @@ class Agent:
                     return llm_result + "\n任务结束: 任务完成 或 进行循环 或 目标偏离"
                 
             messages = self._get_llm_messages()
-            if self._show_step_detail:
-                self.stream_output(f'\n全部消息: {str(self.messages)}\n')
+            if self._show_messages:
+                messages_str = json.dumps(messages, indent=4, ensure_ascii=False).replace('```', '\`\`\`')
+                self.stream_output(f'\n```messages\n{messages_str}\n```\n')
             
             llm_result, (python_mode, python_data, result, should_continue) = self._llm_and_parse_output(messages)
             self.llm_run_count += 1
@@ -939,7 +943,7 @@ class Agent:
         files = self._read_files + self._tmp_read_files
         if len(files) > 0:
             file_memory = self.get_file_memory([], files, -1)
-            new_messages += [{"role": "assistant", "content": file_memory}]
+            new_messages = new_messages[:-1] + [{"role": "user", "content": file_memory}] + new_messages[-1:]
 
         # 添加system消息
         return new_messages
