@@ -19,6 +19,18 @@ FILE_OPERATOR_PROMPT = """
 - 文件路径不能包含 .. 或 /.. 或 \\..\\ 等上级目录
 - 文件路径不能以 / 或 \ 开头
 - 文件路径不能包含 /etc, /usr, /var, /sys, /proc, /root, /home 等敏感系统路径
+- 文件协议不要以```语言开头，直接以%%FILE_OPERATION%%开头
+  - 例如：
+  错误写法：
+  ```python
+  %%FILE_OPERATION%%
+  read test.py
+  %%END%%
+  ```
+  规范写法：
+  %%FILE_OPERATION%%
+  read test.py
+  %%END%%
 
 ## 重要规则
 
@@ -43,6 +55,12 @@ read 文件路径
 start_line=[开始行号]
 end_line=[结束行号]
 %%END%%
+- 当不指定开始行号和结束行号时，默认读取全部内容
+- 读取案例：
+%%FILE_OPERATION%%
+read test.txt
+%%END%%
+
 
 ### 写入文件
 
@@ -71,6 +89,26 @@ update 文件路径
 >>>>>>> REPLACE
 %%END%%
 注意：查找替换时应该忽略行号
+- 修改案例：
+收到的内容：
+1: 你好世界
+2: 你好codyer
+修改要求：修改codyer为codyer_coderun
+
+这时候，去除行号实际内容是：
+你好世界
+你好codyer
+
+那么需要输出：
+%%FILE_OPERATION%%
+update 文件路径
+%%CONTENT%%
+<<<<<<< SEARCH
+你好codyer
+=======
+你好codyer_coderun
+>>>>>>> REPLACE
+%%END%%
 
 ### 删除文件内容
 
@@ -144,6 +182,82 @@ def _is_safe_path(file_path: str) -> bool:
     return True
 
 
+def parse_llm_file_read(input: str) -> Optional[str]:
+    """
+    专门解析大模型输出的文件读取操作
+    只处理read操作，实时返回结果
+    """
+    import re
+    
+    try:
+        # 查找所有的 FILE_OPERATION 块
+        operations = _find_all_file_operations(input)
+        
+        if not operations:
+            return None  # 没有找到操作，不做处理
+        
+        results = []
+        for i, operation_text in enumerate(operations):
+            try:
+                operation_data = _parse_file_operation_format(operation_text)
+                # 只处理读取操作
+                if operation_data["operation"] == "read":
+                    result = _execute_file_operation(operation_data)
+                    results.append(f"读取操作 {i+1}: {result}")
+            except Exception as e:
+                try:
+                    operation_data = _parse_file_operation_format(operation_text)
+                    if operation_data["operation"] == "read":
+                        results.append(f"读取操作 {i+1} 失败: {str(e)}")
+                except:
+                    # 如果解析失败，检查是否包含read关键字
+                    if "read " in operation_text:
+                        results.append(f"读取操作 {i+1} 失败: {str(e)}")
+        
+        return "\n".join(results) if results else None
+        
+    except Exception as e:
+        return f"读取操作错误：{str(e)}"
+
+
+def parse_llm_file_operate_no_read(input: str) -> Optional[str]:
+    """
+    解析大模型输出的文件操作（不包括读取操作）
+    处理write、append、update、delete等操作
+    """
+    import re
+    
+    try:
+        # 查找所有的 FILE_OPERATION 块
+        operations = _find_all_file_operations(input)
+        
+        if not operations:
+            return None  # 没有找到操作，不做处理
+        
+        results = []
+        for i, operation_text in enumerate(operations):
+            try:
+                operation_data = _parse_file_operation_format(operation_text)
+                # 排除读取操作，处理其他操作
+                if operation_data["operation"] != "read":
+                    result = _execute_file_operation(operation_data)
+                    results.append(f"操作 {i+1}: {result}")
+            except Exception as e:
+                try:
+                    operation_data = _parse_file_operation_format(operation_text)
+                    if operation_data["operation"] != "read":
+                        results.append(f"操作 {i+1} 失败: {str(e)}")
+                except:
+                    # 如果解析失败，检查是否不是read操作
+                    if "read " not in operation_text and "%%FILE_OPERATION%%" in operation_text:
+                        results.append(f"操作 {i+1} 失败: {str(e)}")
+        
+        return "\n".join(results) if results else None
+        
+    except Exception as e:
+        return f"文件操作错误：{str(e)}"
+
+
 def parse_llm_file_operate(input: str) -> Optional[str]:
     """
     解析大模型输出的文件操作
